@@ -11,10 +11,10 @@ Including realtime news and old article.
     appledaily
 """
 
-__author__ = "GrapherD (LouieLu) (grapherd at gmail.com)"
+__author__ = "Louie Lu (GrapherD) <grapherd at gmail.com>"
 __license__ = "MIT"
-__version__ = "0.0.2"
+__version__ = "0.1.0"
 
-from gettitle import *
+from newstitle.gettitle import *
 
 support_news = gettitle.__all__
